Error

Enum Error 

pub enum Error<'args> {
    Uncaught(Uncaught),
    ShortsUnknown {
        shorts: &'args OsStr,
    },
    FlagUnknown {
        flag: &'args OsStr,
    },
    FlagUnexpectedToggle {
        flag: &'args OsStr,
    },
    FlagUnexpectedValue {
        flag: &'args OsStr,
        value: &'args OsStr,
    },
    FlagNoValue {
        flag: &'args OsStr,
    },
    FlagValueNotUtf8 {
        flag: &'args OsStr,
        value: &'args OsStr,
    },
    ParameterUnexpected {
        parameter: &'args OsStr,
    },
    ParameterNotUtf8 {
        parameter: &'args OsStr,
    },
}
Enumeration of all possible errors that can be reported by the program argument parser.

Variants



Uncaught(Uncaught)

Uncaught error forwarded from a report.



ShortsUnknown

The given short-option flags are unknown and cannot be handled. The flags are provided without the leading dash. Multiple consecutive flags can be reported in a single error.

Fields

shorts: &'args OsStr


FlagUnknown

The given flag is unknown and cannot be handled.

Fields

flag: &'args OsStr


FlagUnexpectedToggle

The given flag is known but was specified with the toggle-prefix no-, which is not valid for this flag.

Fields

flag: &'args OsStr


FlagUnexpectedValue

The given flag is known but was provided an inline value despite not taking any values.

Fields

flag: &'args OsStr
value: &'args OsStr


FlagNoValue

The given flag is known but was provided no value despite requiring one.

Fields

flag: &'args OsStr


FlagValueNotUtf8

A flag value was specified as invalid UTF-8, despite the flag requiring valid UTF-8 values.

Fields

flag: &'args OsStr
value: &'args OsStr


ParameterUnexpected

A command parameter was specified but the current command does not take parameters.

Fields

parameter: &'args OsStr


ParameterNotUtf8

A command parameter was specified as invalid UTF-8, despite the given command requiring valid UTF-8 parameters.

Fields

parameter: &'args OsStr