Token

Enum Token 

pub enum Token<'tk> {
    Colon,
    Comma,
    ArrayOpen,
    ArrayClose,
    ObjectOpen,
    ObjectClose,
    Null,
    False,
    True,
    Whitespace {
        raw: Cow<'tk, str>,
    },
    Number {
        raw: Cow<'tk, str>,
        integer: Cow<'tk, [u8]>,
        fraction: Cow<'tk, [u8]>,
        exponent: Cow<'tk, [u8]>,
        integer_sign: Sign,
        exponent_sign: Sign,
    },
    String {
        raw: Cow<'tk, str>,
        chars: Cow<'tk, str>,
    },
}
Enumeration of all possible tokens that can be yielded by the tokenizer.

Note that tokens can reference temporary values of the tokenizer (tied to the lifetime 'tk). Use Token::own() to duplicate these values and provide an unrestricted copy of the token.

Variants



Colon

JSON colon token



Comma

JSON comma token



ArrayOpen

JSON open-array token



ArrayClose

JSON close-array token



ObjectOpen

JSON open-object token



ObjectClose

JSON close-object token



Null

JSON null keyword



False

JSON false keyword



True

JSON true keyword



Whitespace

Block of continuous whitespace

Fields

raw: Cow<'tk, str>


Number

JSON number value

Fields

raw: Cow<'tk, str>
integer: Cow<'tk, [u8]>
fraction: Cow<'tk, [u8]>
exponent: Cow<'tk, [u8]>
integer_sign: Sign
exponent_sign: Sign


String

JSON string value

Fields

raw: Cow<'tk, str>
chars: Cow<'tk, str>

Implementations

Source

impl<'tk> Token<'tk>

pub fn own(self) -> Token<'static>

Create owned version of a token.

For performance reasons, tokens reference internal data of the tokenizer. This duplicates all this referenced data and returns an equivalent token but without the lifetime restriction.