pub enum Token<'tk> {
Colon,
Comma,
ArrayOpen,
ArrayClose,
ObjectOpen,
ObjectClose,
Null,
False,
True,
Whitespace {
raw: Cow<'tk, str>,
},
Number {
raw: Cow<'tk, str>,
integer: Cow<'tk, [u8]>,
fraction: Cow<'tk, [u8]>,
exponent: Cow<'tk, [u8]>,
integer_sign: Sign,
exponent_sign: Sign,
},
String {
raw: Cow<'tk, str>,
chars: Cow<'tk, str>,
},
}Expand description
Enumeration of all possible tokens that can be yielded by the tokenizer.
Note that tokens can reference temporary values of the tokenizer (tied to
the lifetime 'tk). Use Token::own() to duplicate these values and
provide an unrestricted copy of the token.
Variants
Colon
JSON colon token
Comma
JSON comma token
ArrayOpen
JSON open-array token
ArrayClose
JSON close-array token
ObjectOpen
JSON open-object token
ObjectClose
JSON close-object token
Null
JSON null keyword
False
JSON false keyword
True
JSON true keyword
Whitespace
Block of continuous whitespace
Number
JSON number value
Fields
String
JSON string value
Implementations